# Save frame placeholders

| Placeholder  | Description                          | Example   |
| ------------ | ------------------------------------ | --------- |  
| script_name  | Script name without extension        | haruhi_01 |
| index        | Video node number (zero-based)       | 0         |
| node_name    | Video node name                      | src       |
| format       | Video format of the clip             | YUV420P10 |
| frame        | Current frame number (zero-based)    | 55369     |
| total_frames | Number of frames in clip             | 151008    |
| width        | Width of frame in pixels             | 1920      |
| height       | Height of frame in pixels            | 1080      |
| fps_num      | FPS numerator                        | 24000     |
| fps_den      | FPS denominator                      | 1001      |
| matrix       | Matrix coefficients of the clip      | 709       |
| primaries    | Color primaries of the clip          | 709       |
| transfer     | Transfer characteristics of the clip | 709       |
| range        | Color range of the clip              | limited   |
